@@ -14,15 +14,16 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.2.6'
+__version__ = 'v1.2.8'
 
 class TranslateJson(object):
-    def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook):
+    def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook, output_xmind):
         self.js_file = js_file
         self.link_path = link_path
         self.dir_type = dir_type
         self.output_md = output_md
         self.output_gitbook = output_gitbook
+        self.output_xmind = output_xmind
 
         self.gitbookpath = ''
         self.markdownpath = ''
@@ -41,6 +42,7 @@ class TranslateJson(object):
         self.max_len = ''
         self.reg_rst = '寄存器详细说明\n==============\n\n.. toctree::\n'
         self.reg_rst += '   :caption: Contents:\n\n'
+        self.xmind_md = '# REG\n## register\n'
 
     def get_dpath(self, in_dict, pre_path = ''):
         path_list = []
@@ -375,6 +377,8 @@ class TranslateJson(object):
             return -1
     
         des = self.get_delem(self.js_dict, dpath, key = 'Description')
+        #self.xmind_md += '### ' + name + '\n' + '> ' + des + '\n'
+        self.xmind_md += '### ' + name + '\n'
         fields = self.get_delem(self.js_dict, dpath, key = 'Fields')
         reserve_fields = self.get_reserve_fields(fields)
         fields.extend(reserve_fields)
@@ -416,6 +420,9 @@ class TranslateJson(object):
             #f = fields[fields_len - i -1]
             f = fields[i]
             if f['name'] != 'reserved':
+                #self.xmind_md += '* ' + f['name'] + '\n    * ' + f['description'] + '\n'
+                self.add_xmind_md(f['name'], f['description'])
+
                 line = self.add_description_table(lm, [f['range'], f['name'], \
                         f['access'], f['reset_value'], f['description']])
                 register_data += line
@@ -441,6 +448,24 @@ class TranslateJson(object):
             with open(file_path, 'w') as fd:
                 fd.write(register_data)
             self.reg_data += '{% include "./' + name +  '.md" %}\n'
+
+    def add_xmind_md(self, name, des):
+        self.xmind_md += '* ' + name + '\n'
+        des = des.replace('：',':').replace('；',';')
+        if re.findall(';[0-9]:|。[0-9]:', des):
+            for tmp_des in re.split('[;。]', des):
+                tmp_des = tmp_des.strip(' ')
+                if not re.match('^[0-9]:', tmp_des):
+                    self.xmind_md += '* > ' + tmp_des + '\n'
+            for tmp_des in re.split('[;。]', des):
+                tmp_des = tmp_des.strip(' ')
+                if re.match('^[0-9]:', tmp_des):
+                    self.xmind_md += '    * ' + tmp_des + '\n'
+        else:
+            for tmp_des in re.split('[。]', des)[1:]:
+                self.xmind_md += '* > ' + tmp_des + '\n'
+            tmp_des = re.split('[。]', des)[0]
+            self.xmind_md += '    * ' + tmp_des + '\n'
     
     def add_description(self, name, des, access):
         des = des.replace("；", ";")
@@ -602,6 +627,12 @@ class TranslateJson(object):
             self.create_all_reg_data(lm)
             self.data = "# 寄存器列表\n" + self.all_reg_data + "\n"\
                     + "# 寄存器详细说明\n" + self.data.replace("#", "##")
+            if self.output_xmind:
+                md_file = file_msg + '.md'
+                with open(md_file, 'w') as fd:
+                    fd.write(self.xmind_md)
+                    print("\n\tcreate " + md_file + " success") 
+                    return
             with open(md_file, 'w') as fd:
                 fd.write(self.data)
             print("\n\tcreate " + md_file + " success") 
@@ -625,11 +656,12 @@ def main():
     if len(sys.argv) <= 1:
             usage()
             sys.exit()
-    opts,args = getopt(sys.argv[1:],"f:l:ghv")
+    opts,args = getopt(sys.argv[1:],"f:l:gxhv")
     js_file = "demo.json"
     link_path = ''
     output_md = 1
     output_gitbook = 0
+    output_xmind = 0
     dir_type = "alone"
     for k,v in opts:
         if k == "-f":
@@ -642,6 +674,8 @@ def main():
         if k == "-g":
             output_gitbook = 1
             output_md = 0
+        if k == "-x":
+            output_xmind = 1
         if k == "-h":
             usage()
             sys.exit()
@@ -649,7 +683,7 @@ def main():
             print(__version__)
             sys.exit()
     #print("opts:", opts, "args", args)
-    tj = TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook)
+    tj = TranslateJson(js_file, link_path, dir_type, output_md, output_gitbook, output_xmind)
     tj.main()
 
 if __name__ == "__main__":
